lower_target_plan

Function lower_target_plan 

pub fn lower_target_plan(
    plan: &TargetPlan,
) -> Result<ExecutableTargetPlan, TargetPlanGap>
Lower every semantic axis independently into the runtime target algebra.

Errors

Returns a gap when the runtime cannot represent a semantic operation or fallback.